#
# spec file for package libisoburn
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 1
Name:           libisoburn
Version:        1.5.6
Release:        1.5
Summary:        Frontend for libburn and libisofs
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Record
URL:            https://libburnia-project.org/
Source0:        https://files.libburnia-project.org/releases/%{name}-%{version}.tar.gz
Source1:        https://files.libburnia-project.org/releases/%{name}-%{version}.tar.gz.sig
# keyring from https://dev.lovelyhq.com/libburnia/web/wiki/Releases
Source10:       keyring.asc
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libacl-devel
BuildRequires:  libburn-devel
BuildRequires:  libisofs-devel
BuildRequires:  libjte-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  zlib-devel

%description
Libisoburn is a frontend for libraries libburn and libisofs which enables
creation and expansion of ISO-9660 filesystems on all CD/DVD/BD media supported
by libburn. This includes media like DVD+RW, which do not support multi-session
management on media level and even plain disk files or block devices. Since it
specializes on data files in ISO-9660 filesystem images it is not suitable for
audio (CD-DA) or any other CD layout which does not entirely consist of
ISO-9660 sessions.

%package devel
Summary:        Development Files for libburn
Group:          Development/Libraries/C and C++
Requires:       libburn-devel
Requires:       libisoburn%{so_ver} = %{version}
Requires:       libisofs-devel
# libburnia-devel was last used in version 1.4.0
Provides:       libburnia-devel = %{version}
Obsoletes:      libburnia-devel < %{version}

%description devel
Development files for developing applications using libisoburn.

%package -n libisoburn%{so_ver}
Summary:        Frontend for libburn and libisofs
Group:          System/Libraries

%description -n libisoburn%{so_ver}
Libisoburn is a frontend for libraries libburn and libisofs which enables
creation and expansion of ISO-9660 filesystems on all CD/DVD/BD media supported
by libburn. This includes media like DVD+RW, which do not support multi-session
management on media level and even plain disk files or block devices. Since it
specializes on data files in ISO-9660 filesystem images it is not suitable for
audio (CD-DA) or any other CD layout which does not entirely consist of
ISO-9660 sessions.

%package -n xorriso
Summary:        ISO 9660 Rock Ridge Filesystem Manipulator
Group:          Productivity/Multimedia/CD/Record
Requires(post): info
Requires(preun):info
# libburnia-tools was last used in version 1.4.0
Provides:       libburnia-tools = %{version}
Obsoletes:      libburnia-tools < %{version}
# libburnia-tools-x11 was last used in version 1.4.0
Provides:       libburnia-tools-x11 = %{version}
Obsoletes:      libburnia-tools-x11 < %{version}

%description -n xorriso
xorriso is a program which maps file objects from POSIX compliant filesystems
into Rock Ridge enhanced ISO 9660 filesystems and allows session-wise
manipulation of such filesystems. It can load the management information of
existing ISO images and it writes the session results to optical media or to
filesystem objects.
Vice versa xorriso is able to restore file objects from ISO 9660 filesystems.

%package -n xorriso-tcltk
Summary:        Graphical frontend for xorriso
Group:          Productivity/Multimedia/CD/Record
Requires:       tcl
Requires:       tk
Requires:       xorriso = %{version}

%description -n xorriso-tcltk
xorriso is a program which maps file objects from POSIX compliant filesystems
into Rock Ridge enhanced ISO 9660 filesystems and allows session-wise
manipulation of such filesystems. It can load the management information of
existing ISO images and it writes the session results to optical media or to
filesystem objects.

This package provides a graphical frontend to xorriso.

%prep
%setup -q

# Remove build time references so build-compare can do its work
echo "HTML_TIMESTAMP = NO" >> doc/doxygen.conf.in

%build
%configure --disable-static
make %{?_smp_mflags}
doxygen doc/doxygen.conf

%install
%make_install

# Remove libtool config files
find %{buildroot} -type f -name "*.la" -delete -print

# Install devel docs
mkdir -p %{buildroot}%{_docdir}/%{name}-devel
cp -a doc/html/ %{buildroot}%{_docdir}/%{name}-devel/

%fdupes -s %{buildroot}%{_docdir}/%{name}-devel/

%post -n libisoburn%{so_ver} -p /sbin/ldconfig
%postun -n libisoburn%{so_ver} -p /sbin/ldconfig

%post -n xorriso
%install_info --info-dir="%{_infodir}" "%{_infodir}/xorriso.info%{ext_info}"
%install_info --info-dir="%{_infodir}" "%{_infodir}/xorrisofs.info%{ext_info}"
%install_info --info-dir="%{_infodir}" "%{_infodir}/xorrecord.info%{ext_info}"

%post -n xorriso-tcltk
%install_info --info-dir="%{_infodir}" "%{_infodir}/xorriso-tcltk.info%{?ext_info}"

%preun -n xorriso
%install_info_delete --info-dir="%{_infodir}" "%{_infodir}/xorriso.info%{ext_info}"
%install_info_delete --info-dir="%{_infodir}" "%{_infodir}/xorrisofs.info%{ext_info}"
%install_info_delete --info-dir="%{_infodir}" "%{_infodir}/xorrecord.info%{ext_info}"

%preun -n xorriso-tcltk
%install_info_delete --info-dir="%{_infodir}" "%{_infodir}/xorriso-tcltk.info%{?ext_info}"

%files devel
%license COPYING
%doc AUTHORS COPYRIGHT ChangeLog README TODO
%doc doc/partition_offset.wiki
%doc %{_docdir}/%{name}-devel/html/
%{_includedir}/libisoburn/
%{_libdir}/pkgconfig/libisoburn-1.pc
%{_libdir}/libisoburn.so

%files -n libisoburn%{so_ver}
%{_libdir}/libisoburn.so.%{so_ver}*

%files -n xorriso
%license COPYING
%doc COPYRIGHT
%doc doc/{qemu_xorriso.wiki,startup_file.txt}
%doc xorriso/README_gnu_xorriso
%{_bindir}/osirrox
%{_bindir}/xorrecord
%{_bindir}/xorriso
%{_bindir}/xorrisofs
%{_bindir}/xorriso-dd-target
%{_mandir}/man1/xorriso.1%{?ext_man}
%{_mandir}/man1/xorriso-dd-target.1%{?ext_man}
%{_mandir}/man1/xorrisofs.1%{?ext_man}
%{_mandir}/man1/xorrecord.1%{?ext_man}
%{_infodir}/xorriso.info%{?ext_info}
%{_infodir}/xorriso-dd-target.info%{?ext_info}
%{_infodir}/xorrisofs.info%{?ext_info}
%{_infodir}/xorrecord.info%{?ext_info}

%files -n xorriso-tcltk
%doc frontend/README-tcltk
%{_bindir}/xorriso-tcltk
%{_mandir}/man1/xorriso-tcltk.1%{?ext_man}
%{_infodir}/xorriso-tcltk.info%{?ext_info}

%changelog
* Wed Aug 30 2023 Adam Majer <adam.majer@suse.de>
- update to 1.5.6: (jsc#PED-5018)
  * Bug fix: False -status failure with -boot_image --interval:appended_partition
  * Bug fix: -no_rc prevented pre-scanning of arguments for stdio output and
    others. Introduced by mistake in a62f6af5, 2011.10.18.162119.
  * Bug fix: -not_leaf and -not_paths were not applied to -extract and alike
  * Bug fix: -report_system_area cmd misperceived -part_like_isohybrid with
  - isohybrid-gpt-basdat
  * Bug fix: -report_system_area cmd misperceived combination of isohybrid and
    appended partition in GPT
  * Bug fix: -as mkisofs option -part_like_isohybrid did not cause a MBR
    partition table if the partitions are data files in the ISO
    rather than appended
  * Bug fix: Split file directories (-split_size) were created with wrong
    permissions
  * Bug fix: libisofs did not mark clones of imported files as imported.
    This could cause that original and clone occupy data storage
    in the newly written session. Thanks to Ivan Shmakov.
  * Bug fix: Partition offset was preserved from -indev rather than from -outdev
  * Bug fix: libisofs could misrepresent Rock Ridge information if many
    symbolic links or AAIP data were recorded in a directory
  * Bug fix: Data files named /boot.catalog or ./boot.cat could be left out of
    the emerging ISO if the boot catalog was set to be hidden
  * Bug fix: -toc reported wrong track LBA with overwritable media with
    unrecognized content (pseudo-closed)
  * Bug fix: -find test -has_xattr matched "isofs." attributes
    in -xattr mode "any"
  * New API call isoburn_assess_written_features()
  * New API calls isoburn_igopt_set_max_ce_entries(),
    isoburn_igopt_get_max_ce_entries()
  * New flag bit12 with isoburn_read_iso_head():
    Read even if start of multi-session emulation is damaged
  * New -boot_image settings gpt_iso_bootable= and gpt_iso_not_ro=
  * New -as mkisofs options --gpt-iso-bootable and --gpt-iso-not-ro
  * New -as cdrecord option --obs_pad. Automatic no_emul_toc with -as cdrecord.
  * New parameters "obs_pad" and "bdr_obs_exempt" for -dvd_obs
  * New -as cdrecord option --bdr_obs_exempt
  * New command -assess_indev_features
  * New -find test -size
  * New -compliance rules max_ce_entries=, max_ce_drop=
  * Allowed lseekable device files with -cut_out.
* Tue Feb 23 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.4:
  * Bug fix: -report_system_area as_mkisofs misrepresented GPT with appended
    partition and forced boot flag as -part_like_isohybrid
  * Bug fix: Boot catalog could get a wrong name if cat_path= is explicitely
    given but not containing a slash character
  * New helper script xorriso-dd-target
  * New command -truncate_overwritable
  * Switched to usage of libjte-2.0.0
  * New -jigdo parameters "checksum_algorithm", "demand_checksum", "-checksum-list"
  * New -as mkisofs options "-jigdo-checksum-algorithm", "-checksum-list", "-jigdo-force-checksum"
  * New -read_speed prefixes "soft_force:" and "soft_corr:"
  * New -check_media option data_to="-" for standard output
  * New -zisofs parameters version_2=, block_size_v2=, max_bpt=, max_bpt_f=,
    bpt_target=, bpt_free_ratio=, by_magic=v2, susp_z2=
  * New -as mkisofs options --zisofs-version-2, --zisofs2-susp-z2,
  - -zisofs2-susp-zf
  * Enabled recognition of zisofs by magic without zlib support
  * New -osirrox option sparse= controls extraction into sparse files
  * New libisoburn extension options isoburn_ropt_map_joliet_stripped and
    isoburn_ropt_map_joliet_unmapped
  * New command -joliet_map
  * New command -extract_boot_images
  * New API call isoburn_ropt_get_tree_loaded()
* Thu Aug 20 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5.2:
  * Bug fix: -disk_pattern on -add ./ -- mistook "./" for the root directory
  * Bug fix: -disk_pattern on -add "" -- yielded SIGSEGV
  * Bug fix: -osirrox "concat_split_on" worked only together with -split_size
  larger than 0. Thanks William Willems.
  * New API calls isoburn_igopt_set_part_type_guid(),
    isoburn_igopt_get_part_type_guid(), isoburn_igopt_set_iso_type_guid(),
    isoburn_igopt_get_iso_type_guid()
  * Enabled GPT type GUIDs with -append_partition,
  - boot_image any iso_mbr_part_type=, and -as mkisofs -iso_mbr_part_type
  * Made libisoburn and GNU xorriso ready for building out-of-source.
    Thanks Ross Burton.
* Thu Nov  1 2018 Asterios Dramis <asterios.dramis@gmail.com>
- Update to 1.5.0:
  * Bug fix: Multi-session emulation was not recognized with
    non-zero partition offset
  * New bit10 of isoburn_drive_aquire() to accept all xattr
    namespaces
  * New -xattr mode "any" to process all xattr namespaces of local
    filesystem
  * New -as mkisofs option --xattr-any
  * New -as mkisofs options -uid and -gid
* Tue Apr  3 2018 dimstar@opensuse.org
- Split out xorriso-tcltk from xorriso: The frontend is advertised
  as proof-of-concept by upstream. Additionally, we can save a
  dependency on Tcl/Tk on the main xorriso package.
- Cleanup using spec-cleaner:
  + use SPDX3 license string.
  + Package licence files as license, not doc (boo#1082318).
* Thu Feb  8 2018 asterios.dramis@gmail.com
- Update to 1.4.8:
  * Bug fix: -as mkisofs -no-emul-boot without -boot-load-size
    defaulted to size 4, instead of full boot image size
  * Bug fix: -read_fs "norock" did not prevent reading of root Rock
    Ridge info
  * Bug fix: Mix of absolute and relative disk paths could cause
    SIGSEGV with pattern expansion
  * Bug fix: --mbr-force-bootable did not get into effect with
  - append_partition
  * Bug fix: Exit value of failed -mount command was reported as 0
  * Bug fix: -boot_image actions "keep" and "patch" did not work
    any more. Regression by libisofs 1.4.4.
  * New -find tests -maxdepth and -mindepth
  * New commands -update_lxi and -update_li
  * New API calls isoburn_igopt_set_iso_mbr_part_type(),
    isoburn_igopt_get_iso_mbr_part_type()
  * New -boot_image bootspec iso_mbr_part_type=
  * New -as mkisofs option -iso_mbr_part_type
  * New -as mkisofs option -eltorito-platform
  * Properly refusing on Pseudo Overwritable formatted BD-R
* Sat Feb 25 2017 asterios.dramis@gmail.com
- Use sle_version >= 120300 instead of leap_version >= 420300
  (leap_version does not work).
* Sat Feb 18 2017 asterios.dramis@gmail.com
- Added new build requirement libjte-devel for Tumbleweed and
  Leap >= 42.3.
* Sun Jan 29 2017 asterios.dramis@gmail.com
- Update to 1.4.6:
  * Bug fix: The default setting of -compliance did not apply
    rec_mtime to Joliet and ISO:1999. mkisofs emulation was not
    affected by this bug.
  * Bug fix: -file_size_limit did not increase ISO level if
    necessary. Thanks Mattias Schlenker.
  * New API calls isoburn_igopt_set_gpt_guid(),
    isoburn_igopt_get_gpt_guid()
  * New command -use_immed_bit, new -as cdrecord option
    use_immed_bit=
  * New -volume_date mode "all_file_dates"
  * New -as mkisofs option --set_all_file_dates
  * New bootspec "gpt_disk_guid=", new -as mkisofs option
  - -gpt_disk_guid
  * New -report_system_area modes "gpt_disk_guid", "make_guid"
  * New environment variable SOURCE_DATE_EPOCH
  * New -find action "set_to_mtime"
* Wed Jul 27 2016 asterios.dramis@gmail.com
- Update to 1.4.4:
  * Bug fix: -as mkisofs did not unescape "\=" in the source part
    of pathspecs
  * Bug fix: -boot_image "any" "system_area=/dev/zero" did not
    zeroize loaded data
  * Bug fix: -pathspecs "on" did not properly handle "\\="
  * Bug fix: HFS+ production could cause MBR partition of type 0xEE
    without GPT
  * Bug fix: HFS+ directories could announce more children than
    they actually have
  * Bug fix: The HFS+ filesystem was not marked by in GPT of GRUB2
    hybrid layout
  * Bug fix: When reading an ISO filesystem, the presence of
  - -protective-msdos-label was not recognized if a partition is
    appended
  * Bug fix: xorrisofs option --protective-msdos-label did not work
    if no system area data were given by option -G or alike
  * Bug fix: -modesty_on_drive properties timeout_sec, min_usec,
    max_usec read wrong numbers from the parameter text
  * Letting -as mkisofs --norock revoke the special effect of -r
  * Letting -blank on overwritable media invalidate UDF extended
    descriptors
  * New -pathspecs mode "as_mkisofs"
  * New -boot_image setting mbr_force_bootable=, -as mkisofs
  - -mbr-force-bootable
  * New -boot_image bootspecs appended_part_as=apm,
    part_like_isohybrid=on
  * New -as mkisofs options -appended_part_as_apm,
  - part_like_isohybrid
  * New command -scsi_dev_family, new -as cdrecord option
    drive_scsi_dev_family=
* Sun Jun 26 2016 asterios.dramis@gmail.com
- Update to 1.4.2:
  * Bug fix: -backslash_codes "on" did not work outside quotes and
    with showing "\r"
  * New API calls isoburn_ropt_set_truncate_mode()
    isoburn_ropt_get_truncate_mode()
  * New options with isoburn_ropt_set_extensions():
    isoburn_ropt_map_*
  * New command -modesty_on_drive, new -as cdrecord -immed,
    minbuf=, modesty_on_drive=
  * New command -ecma119_map
  * New command -read_fs
  * New -boot_image action "replay"
  * New command -file_name_limit, -as mkisofs -file_name_limit
  * New -find test -name_limit_blocker.
  * Result of a Coverity audit: 50+ code changes, but no
    easy-to-trigger bugs
* Mon May 25 2015 asterios.dramis@gmail.com
- Update to 1.4.0:
  * Bug fix: -dev or -indev of medium with non-ISO data caused
    SIGSEGV by NULL.
  * New API calls isoburn_igopt_set_appended_as_gpt(),
    isoburn_igopt_get_appended_as_gpt()
  * New API call isoburn_igopt_set_part_flag() and libisofs
    interval reader flags.
  * New -find action "show_stream_id".
  * Optional libisofs interval reader with -append_partition and
    System Area.
  * New -boot_image bootspec "appended_part_as=", new -as mkisofs
    option -appended_part_as_gpt.
  * New -report_system_area formats "cmd" and "as_mkisofs".
* Sun Mar  8 2015 mpluskal@suse.com
- Update to 1.3.8
  * Bug fix: -boot_image grub grub2_mbr= did not work (but -as
    mkisofs --grub2-mbr did work)
  * Bug fix: -boot_image grub2_mbr= prevented -boot_image
    partition_table=on
  * Bug fix: libburn: A final fsync(2) was performed with stdio
    drives, even if -stdio_sync was set to "off".
  * Bug fix: libburn: Wrong stack usage caused SIGBUS on sparc
    when compiled by gcc -O2
  * Bug fix: -blank force:all on DVD+RW had no effect
  * Enabled use of libedit as alternative to libreadline
  * Enabled recording and restoring of extattr on NetBSD
  * New API calls isoburn_igopt_set_stdio_endsync() and
    isoburn_igopt_get_stdio_endsync
  * New bootspecs hppa_*, new -as mkisofs options -hppa-* for
    HP-PA via PALO
  * New -find pseudo tests -use_pattern , -or_use_pattern
  * New -find action report_sections
  * New command -concat
  * New commands -report_system_area and -report_el_torito
* Sat May 31 2014 asterios.dramis@gmail.com
- Update to version 1.3.6.pl01:
  * Bug fix: Command -status produced FAILURE event if no drive was acquired.
    This is a regression introduced by release 1.3.6.
  From version 1.3.6:
  libisoburn and xorriso:
  * Bug fix: -list_speeds did not work any more with old CD drives. Regression
    introduced by release 1.3.4
  * Bug fix: -check_media marked untested sectors in sector map as valid
  * Bug fix: Paths with symbolic links preceding ".." were not interpreted
    properly
  * New isoburn_igopt_set_relaxed() relaxation isoburn_igopt_joliet_utf16
  * New -compliance rule joliet_utf16, new -as mkisofs option -joliet-utf16
  * New -find test -bad_outname, new -find action print_outname
  * New API call isoburn_conv_name_chars()
- Split libisoburn from libburnia and make it a separate package.
- Added xorriso as a subpackage.
- Added the necessary Provides/Obsoletes entries for libburnia-devel,
  libburnia-tools and libburnia-tools-x11.
* Tue Dec 17 2013 gber@opensuse.org
- update libisofs to version 1.3.4
  * Giving sort weight 2 as default to El Torito boot images
  * Encoding HFS+ names in UTF-16 rather than UCS-2.
- update libburn to version 1.3.4
  * Bug fix: Drive error reports were ignored during blanking and
    formatting
  * Bug fix: Drive LG BH16NS40 stalls on inspection of unformatted
    DVD+RW
  * New API call burn_disc_pretend_full_uncond()
- update libisoburn to version 1.3.4
  * Bug fix: Command -blank "as_needed" formatted blank BD-R.
  * Bug fix: -as mkisofs option -log-file put the log file into the
    image
  * Bug fix: -cut_out did not add x-permission to r-permission of
    directory
  * Bug fix: Command -zisofs did not accept all options emitted by
  - status -zisofs
  * Bug fix: -blank force:... failed on appendable or closed media
  * New command -read_speed
  * New -close mode "as_needed", new -as cdrecord option
  - -multi_if_possible
  * New -alter_date types: a-c , m-c , b-c , c
- add rpmlintrc to remove false-positive dependency error
* Thu Aug  8 2013 pascal.bleser@opensuse.org
- update to 1.3.2:
  * cdrskin has acquired the ability to copy audio tracks to .wav files
  * cdrskin can extract CD-TEXT in a form which is readable for humans and for
    cdrskin itself
* Sun Jun 16 2013 jengelh@inai.de
- Explicitly list libattr-devel as BuildRequires
- Remove redundant %%clean section.
* Sun May 26 2013 gber@opensuse.org
- updated libisofs to version 1.3.0
  * Bug fix: GPT header CRC was computed from all 512 bytes rather
    than from 92.
  * Bug fix: Unspecified Expiration Time and Effective Time of ISO
    volume was represented by 0-bytes rather than ASCII '0' digits.
  * Bug fix: Reserved and unused fields of APM entries were not
    zeroed.
  * Bug fix: The protective MBR partition for GPT started at block
    0 instead of 1.
  * New option bits with el_torito_set_isolinux_options() and
    iso_write_opts_set_system_area() to control GRUB2 patching of
    boot image and MBR.
  * New API calls iso_image_set_sparc_core() and
    iso_image_get_sparc_core().
- updated libburn to version 1.3.0
  * Bug fix: Full formatting of BD-RE used certification regardless
    of drive capabilities
  * Bug fix: DVD+R with damaged TOC were reported by -minfo with
    wrong end address
- updated libisoburn to version 1.3.0
  * Bug fix: Disk paths with components '.' or '..' could be
    mistaken for directories.
  * Bug fix: -as mkisofs -print-size failed with -isohybrid-mbr and
    a single boot image. Regression introduced by libisoburn-1.2.8.
  * Bug fix: -as mkisofs -path-list did not switch to --no-emul-toc
    by default.
  * Bug fix: Unspecified Expiration Time and Effective Time of ISO
    volume was represented by 0-bytes rather than ASCII '0' digits.
  * Bug fix: Reserved and unused fields of APM entries were not
    zeroed.
  * Bug fix: GPT header CRC was computed from all 512 bytes rather
    than from 92.
  * Bug fix: The protective MBR partition for GPT started at block
    0 instead of 1.
  * New -boot_image bootspecs grub2_mbr= and grub2_boot_info=
  * New -boot_image bootspec grub2_sparc_core=
  * New -as mkisofs options --grub2-mbr , --grub2-boot-info ,
  - -grub2-sparc-core
  * New -hardlinks mode "lsl_count" / "no_lsl_count"
* Tue Mar 26 2013 gber@opensuse.org
- updated libburn to version 1.2.8
  * New cdrskin option --list_speeds
  * -toc and -minfo now report about tracks in the incomplete
    session
  * New API call burn_disc_get_incomplete_sessions()
  * New burn_toc_entry component .track_status_bits
  * Bug fix: All CD tracks were reported with the sizes of the
    tracks in the first session. Regression introduced with version
    1.2.0 (rev 4552).
  * Bug fix: On some drives the request for minimum speed yielded
    maximum speed
  * New cdrskin option --no_load
  * Bug fix: Speed setting had no effect on BD media
  * New API call burn_read_audio()
  * New API call burn_list_sev_texts()
  * New API call burn_write_opts_set_obs_pad(), ./configure
  - -enable-dvd-obs-pad
  * New cdrskin option --obs_pad
  * Bug fix: CD SAO sessions with data tracks started by an audio
    pause
  * Bug fix: CD tracks were perceived 2 sectors too short. Nice
    with TAO, bad with SAO.
  * Bug fix: cdrskin SIGSEGV if track source was added when no
    drive was available
- updated libisoburn to version 1.2.8
  * Bug fix: -tell_media_space altered the pointers to MD5 of data
    files which stem from a previous session. This produced false
    mismatches with -check_md5_r.
  * Bug fix: CD tracks were reported with the sizes of the tracks
    in the first session.
  * Bug fix: -check_media use=outdev sector_map= stored TOC of
    input drive
  * Bug fix: -hide hfsplus and -as mkisofs -hide-hfsplus had no
    effect.  Thanks to Davy Ho.
  * Bug fix: ./configure did not abort if libburn.h or libisofs.h
    were missing
  * New command -move
  * New -as mkisofs options -eltorito-id , -eltorito-selcrit
  * Bug fix: SIGSEGV by uninitialized local variable with
  - check_media patch_lba0="on". Regression by version 1.0.6
  * Bug fix: -partition_offset 16 kept -isohybrid-gpt-basdat from
    writing MBR partition table entries of type 0xef
  * Bug fix: -rollback did not work if indev and outdev were empty
  * New API calls Xorriso_parse_line() and Xorriso__dispose_words()
  * New API calls Xorriso_fetch_outlists() and
    Xorriso_peek_outlists()
  * New API call Xorriso_start_msg_watcher()
  * New API calls Xorriso__severity_cmp() and
    Xorriso__severity_list()
  * New API calls Xorriso_sieve_add_filter,
  * Xorriso_sieve_get_result, Xorriso_sieve_clear_results,
    Xorriso_sieve_dispose, Xorriso_sieve_big
  * New -boot_image partition_cyl_align mode "all"
  * New -blank mode prefix "force:"
  * New -osirrox settings "blocked" and "unblock"
  * New command -lns for creating symbolic links
  * New command -toc_of
  * New command -msg_op
  * New command -launch_frontend
  * Proof-of-concept of a GUI frontend program: xorriso-tcltk
    written in Tcl/Tk.
  * New API call isoburn_igopt_set_hfsp_serial_number()
  * New API calls isoburn_igopt_set_prep_partition,
    isoburn_igopt_set_efi_bootp
  * New API calls isoburn_igopt_set_hfsp_block_size() and
    isoburn_igopt_get_hfsp_block_size()
  * New -check_media option async_chunks=
  * New xorriso command -write_type
  * New xorriso command -rockridge
  * New xorriso command -hfsplus
  * New -find tests -has_hfs_crtp, has_hfs_bless
  * New -find actions set/get_hfs_crtp,  set/get_hfs_bless
  * New -find test -disk_path
  * New -boot_image bootspec hfsplus_serial=
  * New -boot_image bootspecs hfsplus_block_size= and apm_block_size=
  * New -boot_image bootspecs efi_boot_part, prep_boot_part,
    chrp_boot_part
  * Command -hide allows hiding in HFS+ filesystem
  * New -as cdrecord options -tao -sao -dao
  * New -as mkisofs option -log-file
  * New -as mkisofs option --norock
  * New -as mkisofs option -hfsplus
  * New -as mkisofs option -hfsplus-file-creator-type
  * New -as mkisofs options -hfs-bless and -hfs-bless-by
  * New -as mkisofs option -hfsplus-serial-no
  * New -as mkisofs options -hfsplus-block-size and -apm-block-size
  * New -as mkisofs option -hide-hfsplus, -hide-hfsplus-list
  * New -as mkisofs options -prep-boot-part, -efi-boot-part,
  - chrp-boot-part
  * New -as mkisofs options -isohybrid-gpt-basdat,
  - isohybrid-gpt-hfsplus, -isohybrid-apm-hfsplus
  * Bug fix: Memory corruption when reading bootable image that was
    truncated
  * Bug fix: -update deleted MD5 of files of which only attributes
    had changed
- updated libisofs to version 1.2.8
  * New API call iso_image_get_pvd_times().
  * Bug fix: Image size prediction altered the pointers to MD5 of
    data files which stem from a previous session.
  * Bug fix: Reading damaged Rock Ridge data could cause SIGSEGV by
    NULL.
  * Bug fix: Appended partitions did not obey cylinder alignment
  * Bug fix: Non-zero partition offset zeroized the MBR copies of
    GPT partition table entries
  * Bug fix: Isohybrid production without any boot image led to
    SIGSEGV by NULL
  * Bug fix: Prevented a memory fault when reading damaged Rock
    Ridge information
  * Bug fix: Memory corruption when reading bootable image that was
    truncated before the storage location of the boot catalog
  * Bug fix: Symbol iso_fs_global_id was missing in libisofs.ver.
  * Bug fix: Volume descriptors of Joliet and ISO 9660:1999 beared
    non-zero Effective Date, involuntarily restricting the early
    end of their lifetime.
  * Bug fix: File Structure Version field of ISO 9660:1999 Enhanced
    Volume Descriptor was 1 instead of 2.
  * Bug fix: The separator dot of Joliet names was byte swapped on
    big-endian machines.
  * Bug fix: Joliet name comparison was done as signed bytes and
    thus produced a peculiar sorting order.
  * Bug fix: Partition cylinder alignment worked only if both, El
    Torito and application provided system area data were present.
  * New API function iso_write_opts_set_hfsplus
  * New API functions iso_hfsplus_xinfo_func(),
    iso_hfsplus_xinfo_new(), and new struct iso_hfsplus_xinfo_data.
  * New API call iso_write_opts_set_hfsp_serial_number()
  * New API calls iso_image_hfsplus_bless and
    iso_image_hfsplus_get_blessed(), and new public enum
    IsoHfsplusBlessings.
  * New API calls so_write_opts_set_prep_img(),
    iso_write_opts_set_efi_bootp()
  * New API call iso_write_opts_set_hfsp_block_size()
  * New API call iso_tree_resolve_symlink()
  * New system area sub type CHRP with
    iso_write_opts_set_system_area()
  * New option bits 2 to 8 for GPT and APM with
    el_torito_set_isolinux_options()
  * New flag bit with iso_node_set_attrs() to protect namespace
    "isofs"
  * New IsoHideNodeFlag value LIBISO_HIDE_ON_HFSPLUS
- added new subpackage libburnia-tools-x11 for GUI tools so that
  libburnia-tools does not depend on X11
* Fri May  4 2012 prusnak@opensuse.org
- updated libburn to version 1.2.2
  * Small internal refinements
- updated libisofs to version 1.2.2
  * New API calls isoburn_get_attached_start_lba(), isoburn_attach_start_lba()
  * New API calls isoburn_igopt_set_rr_reloc(), isoburn_igopt_get_rr_reloc()
  * New API calls isoburn_ropt_set_data_cache(), isoburn_ropt_get_data_cache()
  * New commands -x, -list_arg_sorting
  * New command -rr_reloc_dir
  * New command -data_cache_size
  * New -as mkisofs option -rr_reloc, implemented option -hide-rr-moved
  * Now ignoring -as mkisofs -no-split-symlink-components -no-split-symlink-fields
  * Bug fix: -osirrox on:sort_lba_on -extract from / restored nearly nothing
  * Bug fix: -as mkisofs without -graft-points could not handle names with "="
  * Bug fix: Relaxation options joliet_rec_mtime and iso1999_rec_mtime had wrong values
- updated libisoburn to version 1.2.2
  * New API call iso_write_opts_set_rr_reloc()
  * Bug fix: Directory name mapping to ISO level 1 was too liberal if
    iso_write_opts_set_allow_dir_id_ext() was enabled
  * New API call iso_write_opts_set_allow_7bit_ascii()
  * Improved standards compliance for ISO level 1 names with partly relaxed
    constraints.
* Tue Feb 21 2012 prusnak@opensuse.org
- updated libburn to version 1.2.0
  * Bug fix: cdrskin produced a memory fault if interupted before writing began
  * Bug fix: Solaris adapter mishandled write commands which failed on first try
  * Bug fix: Interrupting libburn while drive tray is loading led to endless loop
  * Bug fix: Progress report with blanking and formatting could be bogus
  * New API calls burn_disc_get_leadin_text(), burn_write_opts_set_leadin_text()
  * New API calls for composing CD-TEXT, see doc/cdtext.txt
  * New API call burn_session_by_cue_file() for reading CDRWIN .cue files
  * New API call burn_track_set_isrc_string()
  * New API calls burn_track_set_index(), burn_track_clear_indice()
  * New API calls burn_session_set_start_tno(), burn_session_get_start_tno()
  * New API calls burn_track_set_pregap_size(), burn_track_set_postgap_size()
  * Implemented cdrskin option textfile=
  * Implemented cdrskin option combination -vv -toc for cdtext.dat production
  * Implemented cdrskin options mcn= and isrc=
  * Implemented cdrskin options -scms -copy -nocopy -preemp -nopreemp
  * Implemented cdrskin option index=
  * Partly implemented cdrskin options cuefile= and -text
  * New cdrskin option input_sheet_v07t= for CD-TEXT definition
  * New cdrskin options --cdtext_dummy and --cdtext_verbose
  * New cdrskin options --four_channel --two_channel
  * New cdrskin option cd_start_tno=
  * New cdrskin options sao_pregap=, sao_postgap=
- updated libisofs to version 1.2.0
  * Bug fix: mkisofs emulation did not record mtime in ECMA-119 directories
  * Bug fix: Program abort while drive tray is loading led to endless loop
  * Bug fix: Solaris adapter mishandled write commands which failed on first try
  * Bug fix: libisoburn.ver had a duplicate function entry
  * New relaxations isoburn_igopt_joliet_rec_mtime,
    isoburn_igopt_iso1999_rec_mtime
  * Made -compliance "rec_mtime" default for xorriso
- updated libisoburn to version 1.2.0
  * Extended influence of iso_write_opts_set_dir_rec_mtime() to Joliet and
    ISO 9660:1999.
* Wed Sep 21 2011 gber@opensuse.org
- update libburn to version 1.1.4
  * New API call burn_lookup_device_link()
  * New API call burn_disc_get_phys_format_info()
  * New cdrskin option --device_links
  * New API call burn_disc_next_track_is_damaged()
  * New API call burn_disc_close_damaged()
  * Burning DVD-R DAO with 2 kB size granularity rather than 32 kB
  * New API call burn_allow_drive_role_4()
  * Bugfixes
- update libisofs to version 1.1.4
  * New API call iso_image_get_bootcat()
  * New API call iso_write_opts_set_joliet_long_names()
  * New error codes for oversized file addresses
  * New no_md5 value 2 for API call iso_read_opts_set_no_md5()
  * New option bits 8 and 9 with iso_write_opts_set_system_area()
  * Bugfixes
- update libisoburn to version 1.1.4
  * New option -device_links
  * Enabled extraction of the boot catalog file to disk filesystem
  * New option -list_speeds
  * New option -signal_handling
  * New option -close_damaged
  * New API call isoburn_set_truncate()
  * New relax option isoburn_igopt_joliet_long_names
  * New option -early_stdio_test
  * New options -print_info and -print_mark
  * New -compliance option joliet_long_names
  * -as mkisofs option -joliet-long is now fully functional
  * Burning DVD-R DAO with 2 kB size granularity rather than 32 kB
  * New isoburn_ropt_set_extensions() option isoburn_ropt_nomd5tag
  * New -padding modes "included" and "appended"
  * New bootspec partition_cyl_align=, new -as mkisofs option -partition_cyl_align
  * New -as mkisofs and -as cdrecord option --no_rc
  * Own man page and info document for xorrisofs
  * Bugfixes
- do not use source services and recompress any more as per
  discussion on opensuse-factory@
* Sun Feb 27 2011 reddwarf@opensuse.org
- updated libburn to 1.0.2.pl00
  * Improved recognition of non-seekable stdio pseudo-drives
  * Allowed umask to create stdio-drive files with rw-permissions
    for all
  * cdrskin now refuses to burn if the foreseeable size exceeds
    media capacity
- updated libisoburn to 1.0.2.pl00
  * New API calls isoburn_igopt_set_extensions(),
    isoburn_igopt_old_empty,
    isoburn_igopt_set_untranslated_name_len(),
    isoburn_igopt_set_disc_label(), isoburn_igopt_get_disc_label(),
    isoburn_ropt_set_displacement(),
    isoburn_ropt_get_displacement()
  * xorriso novelties:
  * New options -clone, -cp_clone, -displacement
  * New -find actions update_merge, rm_merge, clear_merge
  * New -as mkisofs options -max-iso9660-filenames, --old-empty,
  - root, -old-root, --old-root-no-md5, --old-root-no-ino,
  - -old-root-dev, -untranslated_name_len, -joliet-long,
  - iso-level 4, -disallow_dir_id_ext, -sparc-boot, -sparc-label
  * Default -abort_on value is now "FAILURE" with batch and
    "NEVER" with dialog
  * New -compliance options untranslated_names,
    untranslated_name_len=, iso_9660_1999, iso_9660_level=number,
    allow_dir_id_ext
  * Disabled TOC emulation with -as mkisofs, may be re-enabled by
  - -emul-toc
  * New bootspec sparc_label=
  * Bufixes
- updated libisofs to 1.0.2
  * New API calls iso_tree_clone(), iso_stream_clone,
    iso_node_xinfo_make_clonable(), iso_node_xinfo_get_cloner(),
    iso_node_get_next_xinfo(), iso_node_remove_all_xinfo(),
    iso_node_remove_tree(), iso_write_opts_set_old_empty(),
    iso_write_opts_set_untranslated_name_len(),
    iso_write_opts_set_allow_dir_id_ext(), iso_memory_stream_new(),
    iso_write_opts_set_disc_label(),
    iso_write_opts_set_will_cancel()
  * New IsoFileSourceIface version 2 with method clone_src()
  * New IsoStreamIface version 4 with method clone_stream()
  * New public function prototype iso_node_xinfo_cloner
  * New public iso_node_xinfo_cloner instance aaip_xinfo_cloner()
  * new system area type 3 = SUN Disk Label for booting SUN SPARC
    systems
  * New error reply code ISO_DISPLACE_ROLLOVER for external data
    sources with address displacement
* Sun Jan 30 2011 gber@opensuse.org
- improved descriptions/summaries
- more precise filelist
* Fri Dec 24 2010 gber@opensuse.org
- corrected group of library subpackages
* Fri Dec 10 2010 reddwarf@opensuse.org
- updated libburn to 0.9.0.pl00
  * Regression fix: SCSI reply data logging was disabled in release 0.8.6
- updated libisofs to 0.6.40
  * New API call iso_write_opts_set_disc_label(), new system area type 3 = SUN Disk Label for booting SUN SPARC systems.
  * New API call iso_write_opts_set_will_cancel() avoids start of write thread and is to be used to inquire the future image size.
  * New error reply code ISO_DISPLACE_ROLLOVER for external data sources with address displacement.
* Thu Dec  2 2010 prusnak@opensuse.org
- updated libburn to 0.8.8.pl00
  * New API call burn_offst_source_new()
  * New API call burn_disc_get_bd_spare_info()
- updated libisoburn to 0.6.4.pl00
  * New API call isoburn_libjte_req()
  * New API calls isoburn_igopt_attach_jte() and isoburn_igopt_detach_jte()
  * New API call isoburn_igopt_set_tail_blocks()
  * New API call isoburn_libjte_req()
  xorriso novelties:
  * New option -jigdo
  * New -as mkisofs options -jigdo-* and -md5-list as of genisoimage
  * New -as mkisofs options -checksum_algorithm_iso, -checksum_algorithm_template
  * New bootspecs mips_path= and mipsel_path= for Debian MIPS releases
  * New -as mkisofs options -mips-boot and -mipsel-boot
  * New option -append_partition, -as mkisofs -append_partition
- updated libisofs to 0.6.38
  * New API calls iso_write_opts_attach_jte() and iso_write_opts_detach_jte()
    allow to use of libjte for jigdo production.
  * New API call iso_write_opts_set_tail_blocks() for tail padding inside
    ISO image.
  * New API call iso_image_generator_is_running() to learn when the write thread
    is done.
  * New API calls iso_image_add_mips_boot_file(),
    iso_image_get_mips_boot_files(), iso_image_give_up_mips_boot().
  * New API call iso_write_opts_set_partition_img() for appending e.g. a small
    empty FAT12 filesystem which may be used on USB stick.
* Fri Sep 24 2010 reddwarf@opensuse.org
- updated libburn to 0.8.6.pl00
  * Lifted test reservation on DVD-R DL media.
  * Hiding all non-API symbols from the linker by use of
  - -version-script
  * Now with history of release notes in ./ChangeLog file.
- updated libisoburn to 0.6.2.pl00
  * New API function isoburn_igopt_set_part_offset()
  * Hiding all non-API symbols from the linker by use of
  - -version-script
  * Now with history of release notes in ./ChangeLog file.
  * Bug fix: Regression with -hardlinks and -compliance old_rr,
    0.4.2, Aug 2009
  * New option -preparer_id, -as mkisofs options -p and -preparer
  * New -boot_image specifier emul_type=none|hard_disk|floppy
  * New boot_image boot specs partition_offset,partition_hd_cyl,
    partition_sec_hd
  * Made behavior of -as mkisofs with unknown options more similar
    to original
  * New -as mkisofs option -hard-disk-boot, enabled -b without
  - no-emul-boot
  * New -as mkisofs option -e from Fedora genisoimage
  * New -as mkisofs options -partition_offset,-partition_hd_cyl,
  - partition_sec_hd
* Wed Sep 15 2010 reddwarf@opensuse.org
- updated libisofs to 0.6.36
  * Can produce ISO images which bear a partiton 1 with non-zero
    start address. They can be mounted from USB stick via the main
    device file (e.g. /dev/sdb) as well as via the partition device
    file (e.g. /dev/sdb1).
* Fri Jul 23 2010 reddwarf@opensuse.org
- updated libburn to 0.8.4.pl00
  * General POSIX system adapters ignore SIGWINCH and SIGURG if
    defined
  * Allowed 64 kB max output buffer size on all OSes
- updated libisoburn to 0.6.0.pl00
  * New option -read_mkisofsrc interprets .mkisofsrc To be
    performed before -as mkisofs. Performed automatically with
    program alias name "xorrisofs".
  * Implemented -as mkisofs options -dir-mode, -file-mode,
  - abstract, -biblio, -copyright
  * Implemented -as mkisofs options -hide, -hide-joliet,
  - hide-list, -hide-joliet-list
  * New -as mkisofs option --boot-catalog-hide
  * New option -hide, -find action -hide, -find test -hidden
  * New -boot_image bootspec cat_hidden=on
  * New options -copright_file , -biblio_file , -abstract_file
  * New find test -disk_name
  * Bug fix: -check_media patch_lba0= could install wrong image
    size
  * Bug fix: -as mkisofs option -volset was wrongly interpreted
    like -volid
- updated libisofs to 0.6.34
  * New API call iso_image_set_boot_catalog_hidden()
  * New API call iso_node_get_hidden()
  * New IsoHideNodeFlag bit LIBISO_HIDE_BUT_WRITE
  * New error code ISO_BOOT_NO_CATALOG
  * Opportunity to reduce compile line length by including "config.h"
- added support for zisofs, ACL and xattr
* Thu Feb 25 2010 prusnak@suse.cz
- updated libburn to 0.7.6
- updated libisoburn to 0.5.0
- updated libisofs 0.6.28
* Tue May 26 2009 prusnak@suse.cz
- updated libburn to 0.6.6
- updated libisoburn to 0.3.8
- updated libisofs to 0.6.18
* Wed Feb 25 2009 prusnak@suse.cz
- updated libburn to 0.6.2
- updated libisoburn to 0.3.2
- updated libisofs to 0.6.12
* Mon Jul 21 2008 prusnak@suse.cz
- created package
  * libburn 0.5.0
  * libisoburn 0.2.2
  * libisofs 0.6.6
